@@ -1,13 +1,13 @@
 use std::path::Path;
 
+use crate::archive::Archive;
+use crate::{HttpArchivePointer, LocalArchivePointer};
 use distribution_filename::WheelFilename;
 use distribution_types::{CachedDirectUrlDist, CachedRegistryDist, Hashed};
 use pep508_rs::VerbatimUrl;
 use pypi_types::HashDigest;
 use uv_cache::{Cache, CacheBucket, CacheEntry};
-
-use crate::archive::Archive;
-use crate::{HttpArchivePointer, LocalArchivePointer};
+use uv_cache_info::CacheInfo;
 
 #[derive(Debug, Clone)]
 pub struct CachedWheel {
@@ -17,6 +17,8 @@ pub struct CachedWheel {
     pub entry: CacheEntry,
     /// The [`HashDigest`]s for the wheel.
     pub hashes: Vec<HashDigest>,
+    /// The [`CacheInfo`] for the wheel.
+    pub cache_info: CacheInfo,
 }
 
 impl CachedWheel {
@@ -32,10 +34,12 @@ impl CachedWheel {
         let archive = path.canonicalize().ok()?;
         let entry = CacheEntry::from_path(archive);
         let hashes = Vec::new();
+        let cache_info = CacheInfo::default();
         Some(Self {
             filename,
             entry,
             hashes,
+            cache_info,
         })
     }
 
@@ -45,6 +49,7 @@ impl CachedWheel {
             filename: self.filename,
             path: self.entry.into_path_buf(),
             hashes: self.hashes,
+            cache_info: self.cache_info,
         }
     }
 
@@ -57,6 +62,7 @@ impl CachedWheel {
             editable: false,
             r#virtual: false,
             hashes: self.hashes,
+            cache_info: self.cache_info,
         }
     }
 
@@ -69,6 +75,7 @@ impl CachedWheel {
             editable: true,
             r#virtual: false,
             hashes: self.hashes,
+            cache_info: self.cache_info,
         }
     }
 
@@ -81,6 +88,7 @@ impl CachedWheel {
             editable: false,
             r#virtual: true,
             hashes: self.hashes,
+            cache_info: self.cache_info,
         }
     }
 
@@ -94,14 +102,17 @@ impl CachedWheel {
 
         // Read the pointer.
         let pointer = HttpArchivePointer::read_from(path).ok()??;
+        let cache_info = pointer.to_cache_info();
         let Archive { id, hashes } = pointer.into_archive();
 
-        // Convert to a cached wheel.
         let entry = cache.entry(CacheBucket::Archive, "", id);
+
+        // Convert to a cached wheel.
         Some(Self {
             filename,
             entry,
             hashes,
+            cache_info,
         })
     }
 
@@ -115,6 +126,7 @@ impl CachedWheel {
 
         // Read the pointer.
         let pointer = LocalArchivePointer::read_from(path).ok()??;
+        let cache_info = pointer.to_cache_info();
         let Archive { id, hashes } = pointer.into_archive();
 
         // Convert to a cached wheel.
@@ -123,8 +135,15 @@ impl CachedWheel {
             filename,
             entry,
             hashes,
+            cache_info,
         })
     }
+
+    #[must_use]
+    pub fn with_cache_info(mut self, cache_info: CacheInfo) -> Self {
+        self.cache_info = cache_info;
+        self
+    }
 }
 
 impl Hashed for CachedWheel {
