@@ -10,7 +10,7 @@ use tracing::debug;
 
 use distribution_types::{
     CachedDist, Diagnostic, InstalledDist, LocalDist, NameRequirementSpecification,
-    ResolutionDiagnostic, UnresolvedRequirementSpecification,
+    ResolutionDiagnostic, UnresolvedRequirement, UnresolvedRequirementSpecification,
 };
 use distribution_types::{
     DistributionMetadata, IndexLocations, InstalledMetadata, Name, Resolution,
@@ -116,16 +116,33 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
 
     // Resolve the requirements from the provided sources.
     let requirements = {
-        // Convert from unnamed to named requirements.
-        let mut requirements = NamedRequirementsResolver::new(
-            requirements,
-            hasher,
-            index,
-            DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
-        )
-        .with_reporter(ResolverReporter::from(printer))
-        .resolve()
-        .await?;
+        // Partition the requirements into named and unnamed requirements.
+        let (mut requirements, unnamed): (Vec<_>, Vec<_>) =
+            requirements
+                .into_iter()
+                .partition_map(|spec| match spec.requirement {
+                    UnresolvedRequirement::Named(requirement) => {
+                        itertools::Either::Left(requirement)
+                    }
+                    UnresolvedRequirement::Unnamed(requirement) => {
+                        itertools::Either::Right(requirement)
+                    }
+                });
+
+        // Resolve any unnamed requirements.
+        if !unnamed.is_empty() {
+            requirements.extend(
+                NamedRequirementsResolver::new(
+                    unnamed,
+                    hasher,
+                    index,
+                    DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
+                )
+                .with_reporter(ResolverReporter::from(printer))
+                .resolve()
+                .await?,
+            );
+        }
 
         // Resolve any source trees into requirements.
         if !source_trees.is_empty() {
@@ -183,15 +200,37 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
     };
 
     // Resolve the overrides from the provided sources.
-    let overrides = NamedRequirementsResolver::new(
-        overrides,
-        hasher,
-        index,
-        DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
-    )
-    .with_reporter(ResolverReporter::from(printer))
-    .resolve()
-    .await?;
+    let overrides = {
+        // Partition the overrides into named and unnamed requirements.
+        let (mut overrides, unnamed): (Vec<_>, Vec<_>) =
+            overrides
+                .into_iter()
+                .partition_map(|spec| match spec.requirement {
+                    UnresolvedRequirement::Named(requirement) => {
+                        itertools::Either::Left(requirement)
+                    }
+                    UnresolvedRequirement::Unnamed(requirement) => {
+                        itertools::Either::Right(requirement)
+                    }
+                });
+
+        // Resolve any unnamed overrides.
+        if !unnamed.is_empty() {
+            overrides.extend(
+                NamedRequirementsResolver::new(
+                    unnamed,
+                    hasher,
+                    index,
+                    DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
+                )
+                .with_reporter(ResolverReporter::from(printer))
+                .resolve()
+                .await?,
+            );
+        }
+
+        overrides
+    };
 
     // Collect constraints and overrides.
     let constraints = Constraints::from_requirements(
