@@ -5,7 +5,7 @@ use anyhow::Result;
 use owo_colors::OwoColorize;
 use tracing::debug;
 
-use distribution_types::{IndexLocations, Resolution};
+use distribution_types::{DependencyMetadata, IndexLocations, Resolution};
 use install_wheel_rs::linker::LinkMode;
 use pep508_rs::PackageName;
 use uv_auth::store_credentials_from_url;
@@ -47,6 +47,7 @@ pub(crate) async fn pip_sync(
     hash_checking: Option<HashCheckingMode>,
     index_locations: IndexLocations,
     index_strategy: IndexStrategy,
+    dependency_metadata: DependencyMetadata,
     keyring_provider: KeyringProviderType,
     allow_insecure_host: Vec<TrustedHost>,
     allow_empty_requirements: bool,
@@ -287,6 +288,7 @@ pub(crate) async fn pip_sync(
         interpreter,
         &index_locations,
         &flat_index,
+        &dependency_metadata,
         &state.index,
         &state.git,
         &state.capabilities,
